summaryrefslogtreecommitdiff
path: root/app/Report
diff options
context:
space:
mode:
authorGreg Roach <greg@subaqua.co.uk>2021-03-16 17:02:29 +0000
committerGreg Roach <greg@subaqua.co.uk>2021-03-18 10:20:57 +0000
commit51928f9a9fc2ab43aa722a5506f11181084ca90c (patch)
tree3557138b1a083007e854f768af646fd234a8fe29 /app/Report
parent6d585cef9ef8b6614104422e11f24f2b5dc95fec (diff)
downloadwebtrees-51928f9a9fc2ab43aa722a5506f11181084ca90c.tar.gz
webtrees-51928f9a9fc2ab43aa722a5506f11181084ca90c.tar.bz2
webtrees-51928f9a9fc2ab43aa722a5506f11181084ca90c.zip
Do not rename parameters in child classes
Diffstat (limited to 'app/Report')
-rw-r--r--app/Report/TcpdfWrapper.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/Report/TcpdfWrapper.php b/app/Report/TcpdfWrapper.php
index 40c8e24c01..1461110b4c 100644
--- a/app/Report/TcpdfWrapper.php
+++ b/app/Report/TcpdfWrapper.php
@@ -41,12 +41,12 @@ class TcpdfWrapper extends TCPDF
*
* @param mixed $h Cell height. Default value: 0.
* @param mixed $y Starting y position, leave empty for current position.
* @param bool $add_page If true add a page, otherwise only return the true/false state
*
* @return boolean true in case of page break, false otherwise.
*/
- public function checkPageBreak($h = 0, $y = '', $add_page = true): bool
+ public function checkPageBreak($h = 0, $y = '', $addpage = true): bool
{
- return parent::checkPageBreak($h, $y, $add_page);
+ return parent::checkPageBreak($h, $y, $addpage);
}
}
@@ -41,12 +41,12 @@ class TcpdfWrapper extends TCPDF
* @param mixed $h Cell height. Default value: 0.
* @param mixed $y Starting y position, leave empty for current position.
- * @param bool $add_page If true add a page, otherwise only return the true/false state
+ * @param bool $addpage If true add a page, otherwise only return the true/false state
*
* @return boolean true in case of page break, false otherwise.